@@ -24,6 +24,7 @@
 *******************************************************************************/
 
 #include <QNetworkProxyQuery>
+#include <QtConcurrentRun>
 
 #include <qmailstore.h>
 #include <qmaillog.h>
@@ -250,10 +251,14 @@ void VkClient::newConnection()
         vkTransport->vkTestConnection();
     }
     if (authorized) {
-        if (status == UpdateProfile)
+        if (status == UpdateProfile) {
+            qDebug() << "retrievalCompleted";
+            emit updateStatus(tr("Configuration tested."));
             emit retrievalCompleted();
-        else
+        } else {
+            qDebug() << "startProcessing";
             emit startProcessing();
+        }
     }
 }
 
@@ -385,20 +390,28 @@ void VkClient::saveTotalOutboxQuantity(QByteArray quantity) {
     this->totalOutboxCount=quantity.toUInt();
     vkTransport->totalOutboxCount=this->totalOutboxCount;
     emit updateStatus(tr("Receive outgoing messages..."));
-    int step=this->totalOutboxCount<VK_MIN_MESSAGES_AT_ONCE ?
-            this->totalOutboxCount : VK_MIN_MESSAGES_AT_ONCE;
+    int step=this->totalOutboxCount < messagesAtOnce ?
+            this->totalOutboxCount : messagesAtOnce;
     setProgress(0, step);
-    emit getSend(0,step);
+    getSendPage(1);
 }
 
 void VkClient::saveTotalInboxQuantity(QByteArray quantity) {
     this->totalInboxCount=quantity.toUInt();
     vkTransport->totalInboxCount=this->totalInboxCount;
     emit updateStatus(tr("Receive incoming messages..."));
-    int step=this->totalOutboxCount<VK_MIN_MESSAGES_AT_ONCE ?
-            this->totalOutboxCount : VK_MIN_MESSAGES_AT_ONCE;
+    int step=this->totalOutboxCount < messagesAtOnce ?
+            this->totalOutboxCount : messagesAtOnce;
     setProgress(0, step);
-    emit getInbox(0, step);
+    getInboxPage(1);
+}
+
+void VkClient::getInboxPage(int page = 1) {
+    emit getInbox(page,messagesAtOnce);
+}
+
+void VkClient::getSendPage(int page = 1) {
+    emit getSend(page,messagesAtOnce);
 }
 
 void VkClient::removeCaptcha() {
@@ -579,11 +592,18 @@ void VkClient::processResponse(VkResponse* response)
     switch (response->action) {
     // The following cases do not relate to input processing
     case VkTransport::updateInboxMessagesAction: {
-        if (!response->midFrom.isEmpty() && !response->midTo.isEmpty())
-            setProgress(response->midFrom.toUInt(), response->midTo.toUInt());
+        uint index = 0;
+        if (!response->midFrom.isEmpty() && !response->midTo.isEmpty()) {
+            index = response->midFrom.toInt();
+        //setProgress(response->midFrom.toUInt(), response->midTo.toUInt());
+            //int from = (response->midFrom.toUInt()-1)*response->midTo.toUInt();
+            //int to = from + response->midTo.toUInt();
+            //int step=this->totalInboxCount < messagesAtOnce ?
+            //        this->totalInboxCount : messagesAtOnce;
+            setProgress(index*messagesAtOnce, totalInboxCount);
+        }
         if (!response->text) {
-            uint index = response->midFrom.toInt();
-            emit getInbox(index, index + messagesAtOnce);
+            getInboxPage(index+1);
         } else {
             qDebug() << "Receiving incoming messages done with status: " << *(response->text);
             // purgeMessageRemovalRecords
@@ -593,12 +613,19 @@ void VkClient::processResponse(VkResponse* response)
         break;
     }
     case VkTransport::updateOutboxMessagesAction: {
-        if (!response->midFrom.isEmpty() && !response->midTo.isEmpty())
-            setProgress(response->midFrom.toUInt(), response->midTo.toUInt());
+        uint index = 0;
+        if (!response->midFrom.isEmpty() && !response->midTo.isEmpty()) {
+            index = response->midFrom.toInt();
+            //setProgress(response->midFrom.toUInt(), response->midTo.toUInt());
+            //int from = (response->midFrom.toUInt()-1)*response->midTo.toUInt();
+            //int to = from + response->midTo.toUInt();
+            //int step=this->totalOutboxCount < messagesAtOnce ?
+            //        this->totalOutboxCount : messagesAtOnce;
+            setProgress(index*messagesAtOnce, totalOutboxCount);
+        }
         if (!response->text) {
-            uint index = response->midFrom.toInt();
             //delete response;
-            emit getSend(index, index+messagesAtOnce);
+            getSendPage(index+1);
             //vkTransport->vkGetSend(index, index+messagesAtOnce);
         } else {
             qDebug() << "Receiving outgoing messages done with status: " << *(response->text);
@@ -654,9 +681,10 @@ void VkClient::processResponse(VkResponse* response)
             if ((response->code == DRV_SERVER_ERROR_CODE)
                 || (response->code == DRV_ACCESS_ERROR_CODE))
                 error = false;
-            else if (response->code != DRV_MESS_ERROR_CODE) {
-                qDebug() << "Standart sending error. Try to ignore.";
-            } else {
+//            else if (response->code != DRV_MESS_ERROR_CODE) {
+//                qDebug() << "Standart sending error. Try to ignore.";
+//            }
+            else {
                 // We don't now what error can be here.
                 qDebug() << "Over error on sending: " << response->code;
                 operationFailed(QMailServiceAction::Status::ErrSystemError, err);
@@ -676,8 +704,11 @@ void VkClient::processResponse(VkResponse* response)
     }
     case VkTransport::infoMessageAction: {
         //updateStatus(QString::number(response->code) + QString(" : ") + *(response->text));
-        updateStatus(*(response->text));
-        if (response->code == DRV_AUTH_SUCCESS_CODE) {
+        if (!authorized) {
+            qDebug() << "Success connected";
+            authorized = true;
+        } else
+        /*if (response->code == DRV_AUTH_SUCCESS_CODE) {
             qDebug() << "Success connected";
             authorized = true;
         } else
@@ -685,22 +716,13 @@ void VkClient::processResponse(VkResponse* response)
             qDebug() << "Broke connected";
             operationFailed(QMailServiceAction::Status::ErrSystemError, QString(*(response->text)));
         } else
-        if (status == DeleteMessage) {
-            if (response->code == DRV_MESS_DEL_CODE) {
-                emit delNextSignal();
-            }
-            else {
-                qDebug() << "Over info on deleting: " << response->code;
-            }
+        if ((status == DeleteMessage) && (response->code == DRV_MESS_DEL_CODE)) {
+            emit delNextSignal();
         } else
-        if (status == SendMessage) {
-            if (response->code == DRV_MESS_SEND_CODE) {
-                emit sendNextSignal();
-            }
-            else {
-                qDebug() << "Over info on sending: " << response->code;
-            }
-        }
+        if ((status == SendMessage) && (response->code == DRV_MESS_SEND_CODE)) {
+            emit sendNextSignal();
+        } else*/
+            //updateStatus(*(response->text));
         qDebug() << "info message was recivied";
         break;
     }
