@@ -79,8 +79,8 @@ VkTransport::VkTransport(QByteArray name)
     vkLog = fopen(QDir::tempPath().append(QDir::separator()).toAscii().append(VK_LOGING_FILE),"w");
 #endif
 
-    // Add dynamic library (libvkontakte.so or libfacebook.so)
-    if ((msa = new QLibrary(LIBNAME)) == 0)
+    // Add dynamic msa library (libvkontakte.so or some else)
+    if (!(msa = new QLibrary(LIBNAME,LIBVERSION)))
         qFatal("Problems with initiation QLibrary object");
 
     msa->setLoadHints(QLibrary::ResolveAllSymbolsHint); // analog RTLD_LAZY
